@@ -5,7 +5,7 @@
 #
 # This file is part of the FleXML XML processor generator system.
 # Copyright (C) 1999 Kristoffer Rose.  All rights reserved.
-# Copyright (C) 2003-2011 Martin Quinson.  All rights reserved.
+# Copyright (C) 2003-2013 Martin Quinson.  All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the Free
@@ -23,8 +23,7 @@
 
 use warnings;
 
-my $Id = '$Id: flexml.pl,v 1.67 2011/11/01 20:49:21 mquinson Exp $ ';
-$Id =~ s/\s*\$\s*//go;
+my $Id = 'FLEXMLVERSION';
 
 # IMPORTS.
 
@@ -166,9 +165,10 @@ sub cquote { # Convert a string to C source format.
 
 sub variablify { # Change XML Name to legal C variable name.
   local ($_) = @_;
+  s|_|___|go;
   s|-|_d_|go;
   s|:|_c_|go;
-  s|/|__|go;
+  s|/|_s_|go;
   $_
 }
 
@@ -180,8 +180,8 @@ sub redistribute { # Print C comment with generated file "license".
   print <<EOT;
 $pre This program was generated with the FleXML XML processor generator.
 $pre FleXML is Copyright (C) 1999-2005 Kristoffer Rose.  All rights reserved.
-$pre FleXML is Copyright (C) 2003-2011 Martin Quinson.  All rights reserved.
-$pre ($Id).
+$pre FleXML is Copyright (C) 2003-2013 Martin Quinson.  All rights reserved.
+$pre (FLEXMLVERSION).
 $pre 
 $pre There are two, intertwined parts to this program, part A and part B.
 $pre
@@ -190,7 +190,7 @@ $pre ------
 $pre 
 $pre Some parts, here collectively called "Part A", are found in the 
 $pre FleXML package.  They are Copyright (C) 1999-2005 Kristoffer Rose
-$pre and Copyright (C) 2003-2011 Martin Quinson. All rights reserved.
+$pre and Copyright (C) 2003-2013 Martin Quinson. All rights reserved.
 $pre
 $pre You can redistribute, use, perform, display and/or modify "Part A"
 $pre provided the following two conditions hold:
@@ -541,7 +541,7 @@ GetOptions(
     "quiet|q" => \$quiet_parser,
     
     # Version!
-    "version|V" => sub { print "FleXML version $Id.\n"; exit 0; },
+    "version|V" => sub { print "FleXML version FLEXMLVERSION.\n"; exit 0; },
 
     # dry-run ?
     "dry-run|n" => \$dryrun,
@@ -588,7 +588,7 @@ GetOptions(
     "actions|a=s" => \$actions
     );
 
-print "FleXML version $Id.\n" if $verbose;
+print "FleXML version FLEXMLVERSION.\n" if $verbose;
 
 # Set DTD file name...and extract prefix for later
 my $prefix = $ARGV[0];
@@ -1238,8 +1238,7 @@ if ($scanner or $standalone) {
 
     if ( /^FLEXML_VERSION$/ ) {
 
-      print "const char rcs_${tagprefix}flexml[] =\n"
-	  . " \"\$\" \"$Id \$\";\n";
+      print "const char ${tagprefix}flexml_version[] = \"FLEXMLVERSION\";\n";
 
       print "const char rcs_${cdtd}_dtd[] =\n"
 	  . " \"\$\" \"$dtdrevision \$\";\n" if $dtdrevision;
